@@ -160,6 +160,7 @@ greeter_ctrl_handler (GIOChannel *source,
 	buf[len-1] = '\0';
 	
 	greeter_item_pam_set_user (buf);
+	greeter_item_ulist_enable ();
 	printf ("%c\n", STX);
 	fflush (stdout);
 	break;
@@ -178,6 +179,7 @@ greeter_ctrl_handler (GIOChannel *source,
 		greeter_probably_login_prompt = FALSE;
 	}
 	greeter_ignore_buttons (FALSE);
+	greeter_item_ulist_enable ();
 	greeter_item_pam_prompt (tmp, PW_ENTRY_SIZE, TRUE);
 	g_free (tmp);
 	break;
@@ -249,10 +251,10 @@ greeter_ctrl_handler (GIOChannel *source,
 	buf[len-1] = '\0';
 
 	tmp = ve_locale_to_utf8 (buf);
-	session = gdm_session_lookup (tmp);
+	session = greeter_session_lookup (tmp);
 	g_free (tmp);
 
-	if (gdm_get_save_session () == GTK_RESPONSE_CANCEL) {
+	if (greeter_save_session () == GTK_RESPONSE_CANCEL) {
 	     printf ("%c%s\n", STX, GDM_RESPONSE_CANCEL);
 	} else {
 	    tmp = ve_locale_from_utf8 (session);
@@ -278,7 +280,7 @@ greeter_ctrl_handler (GIOChannel *source,
     case GDM_SSESS:
         g_io_channel_read_chars (source, buf, PIPE_SIZE-1, &len, NULL); /* Empty */
 
-	if (gdm_get_save_session () == GTK_RESPONSE_YES)
+	if (greeter_save_session () == GTK_RESPONSE_YES)
 	  printf ("%cY\n", STX);
 	else
 	  printf ("%c\n", STX);
@@ -318,8 +320,6 @@ greeter_ctrl_handler (GIOChannel *source,
 	printf ("%c\n", STX);
 	fflush (stdout);
 	greeter_ignore_buttons (FALSE);
-	greeter_item_ulist_enable ();
-
 	break;
 
     case GDM_QUIT:
@@ -532,10 +532,10 @@ greeter_setup_items (void)
   greeter_item_timed_setup ();
   greeter_item_register_action_callback ("ok_button",
 					 greeter_ok_handler,
-					 (gpointer) window);
+					 window);
   greeter_item_register_action_callback ("cancel_button",
 					 greeter_cancel_handler,
-					 (gpointer) window);
+					 window);
   greeter_item_register_action_callback ("language_button",
 					 greeter_language_handler,
 					 NULL);
@@ -1035,6 +1035,7 @@ main (int argc, char *argv[])
   GIOChannel *ctrlch;
   GError *error;
   GreeterItemInfo *root;
+  const gchar *theme_name;
   char *theme_file;
   char *theme_dir;
   gchar *gdm_graphical_theme;
@@ -1341,9 +1342,6 @@ main (int argc, char *argv[])
   gtk_window_move (GTK_WINDOW (window), gdm_wm_screen.x, gdm_wm_screen.y);
   gtk_widget_show_now (window);
 
-  greeter_item_ulist_unset_selected_user ();
-  greeter_item_ulist_enable ();
-
   /* can it ever happen that it'd be NULL here ??? */
   if G_UNLIKELY (window->window != NULL)
     {
